﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web;

namespace SetApplicationNameDynamically
{
    public class SetApplicationName : IHttpModule
    {
        private const string ApplicationNameSetting = "ApplicationName";
        public delegate void MyEventHandler(Object s, EventArgs e);
        private MyEventHandler _eventHandler = null;
        public event MyEventHandler MyEvent
        {
            add { _eventHandler += value; }
            remove { _eventHandler -= value; }
        }

        public void Dispose()
        {
            //throw new NotImplementedException();
        }

        public void Init(HttpApplication context)
        {
            //context.AuthenticateRequest += DetermineApplicationName;
            context.BeginRequest += new EventHandler(OnBeginRequest);
        }

        private static void DetermineApplicationName(object sender, EventArgs e)
        {
            // Access the current Http application.
            HttpApplication application = sender as HttpApplication;
            if (application == null)
            {
                throw new InvalidOperationException("Http application cannot be null.");
            }

            // Get the HttpContext for the current request.
            HttpContext context = application.Context;
            if (context == null)
            {
                throw new InvalidOperationException("Http context cannot be null.");
            }

            // Make the decision based on your requirements, usually by parsing host
            // name or path.
            string applicationName = String.Empty;
            string path = context.Request.Url.AbsolutePath.ToLower();
            //if (path.StartsWith("/MonoXVijay/"))
            if (path.Contains("/DebugHttpModule/"))
                applicationName = "MonoX";
            //else if (path.StartsWith("/MonoXSumit/"))
            else if (path.StartsWith("/DebugModules/"))
                applicationName = "MonoXSumit";

            // Store the application name in the Items collection of the per-request 
            //http context.
            // Storing it in the session state is not an option as the session 
            //is not available at this time.
            context.Items[ApplicationNameSetting] = applicationName;            
        }

        public void OnBeginRequest(Object s, EventArgs e)
        {
            HttpApplication application = s as HttpApplication;
            if (application == null)
            {
                throw new InvalidOperationException("Http application cannot be null.");
            }
            HttpContext context = application.Context;
            if (context == null)
            {
                throw new InvalidOperationException("Http context cannot be null.");
            }

            string applicationName = String.Empty;
            
            string path = context.Request.Url.AbsolutePath.ToLower();
            //context.Response.Write("Context URL from Module: " + path + "<br>");
            //context.Items["ContextURL"] = path;

            if (path.StartsWith("/monoxvijay/"))
            //if (path.StartsWith("/debughttpmodule/"))
                applicationName = "MonoX";
            else if (path.StartsWith("/monoxsumit/"))
            //else if (path.StartsWith("/debugmodules/"))
                applicationName = "MonoXSumit";
            else
                applicationName = "MonoXDevServer";

            //context.Response.Write("Application Name from Module: " + applicationName + "<br>");

            context.Items["ApplicationName"] = applicationName;
            
            if (_eventHandler != null)
                _eventHandler(this, null);
        }
    }
}
